class Sudoku:
    """
    Löst ein Sudoku-Rätsel
    """
    def __init__(self):
        """
        Legt das Sudoku-Feld an und besetzt alle Elemente mit "alle Werte möglich" vor.
        """
        self.feld = [[[nummer for nummer in range(1, 10)] for _ in range(9)] for _ in range(9)]
        
    def Vorbesetzen(self):
        """
        Legt das in der Aufgabe dargestellte Rätsel an.
        """
        besetzungen = [
            (0, 2, 2), (1, 0, 6), (1, 4, 3), (2, 0, 4), (2, 2, 9), (2, 3, 1),
            (2, 4, 6), (2, 5, 7), (2, 8, 3), (3, 1, 1), (4, 2, 8), (4, 5, 4),
            (4, 6, 3), (4, 8, 2), (5, 6, 4), (5, 7, 7), (6, 1, 8), (6, 4, 9),
            (7, 4, 4), (7, 5, 3), (7, 8, 8), (8, 3, 5), (8, 4, 7), (8, 6, 9)
        ]
        for zeile, spalte, wert in besetzungen:
            self.FeldelementFixieren(zeile, spalte, wert)

    def Kopieren(self, original):
        """
        Erstellt eine Kopie des gegebenen Feldes
        :param original: das zu kopierende Feld
        :return: die erstellte Kopie
        """
        return [[list(zelle) for zelle in zeile] for zeile in original]

    def FeldAusgeben(self):
        """
        Gibt das Sudoku-Feld auf der Konsole aus
        Angegeben werden die eindeutigen Felder, sonst "-"
        """
        for zeile in self.feld:
            print(" ".join(str(zelle[0]) if len(zelle) == 1 else '-' for zelle in zeile))
        print()

    def FeldelementFixieren(self, zeile, spalte, wert):
        """
        Legt das Feldelement auf den angegebenen Wert fest.
        :param zeile: Zeilennummer des zu fixierenden Elements
        :param spalte: Spaltennummer des zu fixierenden Elements
        :param wert: der Wert des Elements
        """
        for z in range(9):
            if wert in self.feld[z][spalte]:
                self.feld[z][spalte].remove(wert)
        for s in range(9):
            if wert in self.feld[zeile][s]:
                self.feld[zeile][s].remove(wert)
        box_start_row, box_start_col = 3 * (zeile // 3), 3 * (spalte // 3)
        for i in range(box_start_row, box_start_row + 3):
            for j in range(box_start_col, box_start_col + 3):
                if wert in self.feld[i][j]:
                    self.feld[i][j].remove(wert)
        self.feld[zeile][spalte] = [wert]

    def SchrittAusführen(self, aktuelleZeile, aktuelleSpalte):
        """
        Testet alle Möglichkeiten an der aktuellen Stelle
        :param aktuelleZeile: Nummer der Zeile des aktuellen Elements
        :param aktuelleSpalte: Nummer der Spalte des aktuellen Elements
        """
        startFeld = self.Kopieren(self.feld)
        for wert in startFeld[aktuelleZeile][aktuelleSpalte]:
            self.FeldelementFixieren(aktuelleZeile, aktuelleSpalte, wert)
            if aktuelleZeile == 8 and aktuelleSpalte == 8:
                self.FeldAusgeben()
            else:
                zeile, spalte = aktuelleZeile, aktuelleSpalte + 1
                if spalte > 8:
                    spalte = 0
                    zeile += 1
                self.SchrittAusführen(zeile, spalte)
            self.feld = self.Kopieren(startFeld)

s = Sudoku()
s.Vorbesetzen()
s.FeldAusgeben()
#s.SchrittAusführen()